..
    This file is part of Invenio.
    Copyright (C) 2015-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


===================
 Invenio-Previewer
===================

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-previewer.svg
        :target: https://github.com/inveniosoftware/invenio-previewer/blob/master/LICENSE

.. image:: https://img.shields.io/travis/inveniosoftware/invenio-previewer.svg
        :target: https://travis-ci.org/inveniosoftware/invenio-previewer

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-previewer.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-previewer

.. image:: https://img.shields.io/pypi/v/invenio-previewer.svg
        :target: https://pypi.org/pypi/invenio-previewer


Invenio module for previewing files.

Features:

- File previewing.
- Support for PDF, ZIP, CSV, MARKDOWN, XML, JSON, PNG, JPG and GIF out-of-the-box.
- Extensible API to create new previewers.

Further documentation available: https://invenio-previewer.readthedocs.io/
